@@ -40,9 +40,7 @@ void calculate_placement(void);
 void dump_tree(void);
 
 void activate_mappings(void);
-void account_for_nic_stats(void);
 void clear_cpu_tree(void);
-void pci_numa_scan(void);
 
 /*===================NEW BALANCER FUNCTIONS============================*/
 
@@ -70,6 +68,9 @@ extern unsigned long long cycle_count;
 extern unsigned long power_thresh;
 extern char *banscript;
 extern char *polscript;
+extern cpumask_t banned_cpus;
+extern cpumask_t unbanned_cpus;
+extern long HZ;
 
 /*
  * Numa node access routines
@@ -109,7 +110,7 @@ extern void add_banned_irq(int irq);
 extern void for_each_irq(GList *list, void (*cb)(struct irq_info *info,  void *data), void *data);
 extern struct irq_info *get_irq_info(int irq);
 extern void migrate_irq(GList **from, GList **to, struct irq_info *info);
-extern struct irq_info *add_new_irq(int irq);
+extern struct irq_info *add_new_irq(int irq, const char *irq_name);
 #define irq_numa_node(irq) ((irq)->numa_node)
 
 
