@@ -18,13 +18,17 @@
 #define IRQ_SCSI        2
 #define IRQ_TIMER       3
 #define IRQ_ETH         4
+#define IRQ_GBETH       5
+#define IRQ_10GBETH     6
+#define IRQ_VIRT_EVENT  7
 
 /*
  * IRQ Types
  */
-#define IRQ_TYPE_LEGACY 0
-#define IRQ_TYPE_MSI	1
-#define IRQ_TYPE_MSIX	2
+#define IRQ_TYPE_LEGACY     0
+#define IRQ_TYPE_MSI        1
+#define IRQ_TYPE_MSIX       2
+#define IRQ_TYPE_VIRT_EVENT 3
 
 enum obj_type_e {
 	OBJ_TYPE_CPU,
